@@ -102,6 +102,6 @@ mod tests {
         assert!(!statement.dividends.is_empty());
 
         assert!(statement.open_positions.is_empty());
-        assert!(statement.instrument_info.is_empty());
+        assert!(!statement.instrument_info.is_empty());
     }
 }
\ No newline at end of file
