@@ -271,7 +271,7 @@ mod tests {
         assert!(statement.dividends.is_empty());
 
         assert!(statement.open_positions.is_empty());
-        assert!(statement.instrument_names.is_empty());
+        assert!(statement.instrument_info.is_empty());
     }
 
     #[test]
@@ -314,7 +314,7 @@ mod tests {
         assert!(statement.dividends.iter().any(|dividend| dividend.paid_tax.is_positive()));
 
         assert!(!statement.open_positions.is_empty());
-        assert!(!statement.instrument_names.is_empty());
+        assert!(!statement.instrument_info.is_empty());
     }
 
     #[rstest(name => [
@@ -346,7 +346,7 @@ mod tests {
         let path = format!("testdata/interactive-brokers/{}", name);
         let tax_remapping = tax_remapping.unwrap_or_else(TaxRemapping::new);
         BrokerStatement::read(
-            broker, &path, &hashmap!{}, &hashmap!{}, tax_remapping, &[],
-            ReadingStrictness::all()).unwrap()
+            broker, &path, &Default::default(), &Default::default(), &Default::default(),
+            tax_remapping, &[], ReadingStrictness::all()).unwrap()
     }
 }
\ No newline at end of file
