@@ -1,4 +1,4 @@
-use chrono::{Datelike, Weekday};
+use chrono::{Datelike, Duration, Weekday};
 
 use crate::core::EmptyResult;
 use crate::formatting;
@@ -8,11 +8,11 @@ use crate::types::Date;
 pub enum StatementsMergingStrategy {
     ContinuousOnly,
     SparseOnHolidays(usize),
-    Sparse,
+    SparseSingleDaysLastMonth,
 }
 
 impl StatementsMergingStrategy {
-    pub fn validate(self, first: (Date, Date), second: (Date, Date)) -> EmptyResult {
+    pub fn validate(self, first: (Date, Date), second: (Date, Date), last_end_date: Date) -> EmptyResult {
         let error = |message| {
             let first = formatting::format_period(first);
             let second = formatting::format_period(second);
@@ -29,6 +29,22 @@ impl StatementsMergingStrategy {
                     return error("Non-continuous periods");
                 }
             },
+
+            StatementsMergingStrategy::SparseSingleDaysLastMonth => {
+                if second.0 != first.1 {
+                    let last_month = {
+                        let last_day = last_end_date.pred();
+                        (last_day.year(), last_day.month())
+                    };
+
+                    if second.1 - second.0 == Duration::days(1) && (second.0.year(), second.0.month()) == last_month {
+                        // Some brokers allow to generate only daily statements for the current month
+                    } else {
+                        return error("Non-continuous periods");
+                    }
+                }
+            },
+
             StatementsMergingStrategy::SparseOnHolidays(max_days) => {
                 let mut date = first.1;
                 let mut missing_days = 0;
@@ -43,7 +59,6 @@ impl StatementsMergingStrategy {
                     date = date.succ();
                 }
             }
-            StatementsMergingStrategy::Sparse => {},
         };
 
         Ok(())
