@@ -88,16 +88,17 @@ impl BrokerStatement {
         instrument_names: &HashMap<String, String>, tax_remapping: TaxRemapping,
         corporate_actions: &[CorporateAction], strictness: ReadingStrictness,
     ) -> GenericResult<BrokerStatement> {
-        let jurisdiction = broker.type_.jurisdiction();
+        let broker_jurisdiction = broker.type_.jurisdiction();
 
-        let mut statements = reader::read(
-            broker.type_, statement_dir_path, instrument_internal_ids, tax_remapping, strictness)?;
+        let mut statements = reader::read(broker.type_, statement_dir_path, tax_remapping, strictness)?;
         statements.sort_by(|a, b| a.period.unwrap().0.cmp(&b.period.unwrap().0));
 
         let last_index = statements.len() - 1;
         let last_end_date = statements.last().unwrap().period.unwrap().1;
 
         let mut statement = BrokerStatement::new_empty_from(broker, statements.first().unwrap())?;
+        statement.instrument_info.set_internal_ids(instrument_internal_ids.clone());
+
         let mut dividend_accruals = HashMap::new();
         let mut tax_accruals = HashMap::new();
 
@@ -119,11 +120,11 @@ impl BrokerStatement {
         }
 
         for (dividend_id, accruals) in dividend_accruals {
-            let taxation_type = statement.instrument_info.get_issuer_taxation_type(
-                &dividend_id.issuer, jurisdiction)?;
+            let instrument = statement.instrument_info.get_or_add_by_id(&dividend_id.issuer)?;
+            let taxation_type = instrument.get_taxation_type(broker_jurisdiction)?;
 
             let (dividend, cash_flows) = process_dividend_accruals(
-                dividend_id, taxation_type, accruals, &mut tax_accruals, true)?;
+                dividend_id, &instrument.symbol, taxation_type, accruals, &mut tax_accruals, true)?;
 
             if let Some(dividend) = dividend {
                 statement.dividends.push(dividend);
